==> mls-0.3.5.tar.gz: mls-0.3.5/src/commandimp.h <==
#ifndef __MLS_COMMANDIMP_H__
#define __MLS_COMMANDIMP_H__

#include "define.h"
#include "mlslocale.h"
#include "exception.h"
#include "panel.h"
#include "dialog.h"
#include "mainframe.h"
#include "DirMcd.h"
#include "ZipMcd.h"

namespace MLS {

class CommandImp
{
	private:
		Panel *panel;

	public:
		CommandImp() : panel(NULL)	{ 	}
		~CommandImp() { }
		
		void SetPanel(Panel *p) { panel = p; }
		
		int  Run(const std::string &, bool = false, bool = false);
		int  ParseAndRun(const string &p);
		
		void Default()			{ }
		
		void Key_Enter()		{ panel->Key_Enter();		}
		void Key_Left()			{ panel->Key_Left();	 	}
		void Key_Right() 		{ panel->Key_Right(); 		}
		void Key_Up () 			{ panel->Key_Up();			}
		void Key_Down () 		{ panel->Key_Down();		}
		void Key_Home () 		{ panel->Key_Home();		}
		void Key_End () 		{ panel->Key_End();			}
		void Key_PageUp() 		{ panel->Key_PageUp();		}
		void Key_PageDown() 	{ panel->Key_PageDown();	}
		
		// other implementations	
		void Remove()		    { panel->cmd_remove();	}
		
		void EditConfig()
		{
			Run(e_tConf.extern_editor + " " + e_tConf.home + ".mls/mls.cfg"); 
			
			e_tConf.load((e_tConf.home + ".mls/mls.cfg").c_str());
			panel->Refresh();
		}
		
		void EditColorset()
		{
			Run(e_tConf.extern_editor + " " + e_tConf.home + ".mls/mls.col");
			panel->Refresh();			
		}
		
		void EditKeybind()
		{
			Run(e_tConf.extern_editor + " " + e_tConf.home + ".mls/mls.key"); 
			panel->Refresh();			
		}
		
		void About() 	{	panel->about();			}
		void Help()  	{	panel->cmd_help();		}
		void Exit()  	
		{
			if (e_tConf.QMlsExit == true)
			{
				int nYN = YNBox("Do you really want to quit the mls ?", 0);
				
				if (nYN == YN_N)
				{		
					return;
				}
			}
			
			// 마지막 mls 가 마지막으로 사용한 디렉토리를 저장한다.	
			FILE *fp= fopen((e_tConf.cfghome + "path").c_str(), "wb");
				
			if (fp)
			{
				fputs(panel->GetCurrentPath().c_str(), fp);
				fclose(fp);
			}
			else
			{
				LOG("'path' file write failure !!!");
			}
			g_MainFrame->Exit();
		}
		
		void Menu() 		{	g_MainFrame->tMenu.Process(*panel);	}
		void Refresh()		{	g_MainFrame->RefreshPanel();	}
		void Extract()		{ panel->Key_ZipInstall(); }
		
		void Mcd()
		{
			if (panel->isZip() == false)
			{
				WINDOW*	pWin = NULL;
				
				try
				{
					pWin = MsgWaitBox("Wait", "Please wait !!! - Cancel Key [ESC]");
					
					LOG("Mcd !!!");
					MLS::DirMcd mcd;
					mcd.AddDirectory(panel->GetCurrentPath());
					mcd.setCur(panel->GetCurrentPath());
					
					if (pWin) MsgWaitEnd(pWin);
					
					if (mcd.proc()) 
					{
						panel->Read(mcd.getCur());
					}
				}
				catch(Exception& ex)
				{
					MsgBox(1, "Error", "%s", (char*)ex);
				}
				
				Refresh();
			}
			else
			{
				//MsgBox(1, "Error", "Sorry. Can't view mcd.");
				
				WINDOW*	pWin = NULL;
				
				try
				{
					string sMcdView;
					
					pWin = MsgWaitBox("Wait", "Please wait !!! - Cancel Key [ESC]");
					
					sMcdView = "Mcd - Mls Change Directory [" + panel->m_sZipFile + "]";
					ZipMcd zipmcd(panel->GetZipFiles(), "/", sMcdView.c_str(), panel->m_sZipFile);
					
					zipmcd.AddDirectory(panel->GetZipCurrentPath());
					zipmcd.setCur(panel->GetZipCurrentPath());
					
					if (pWin) MsgWaitEnd(pWin);
					
					if (zipmcd.proc()) 
					{
						LOG("Current Directory [%s]", (zipmcd.getCur()).c_str());
						panel->SetZipCurrentPath(zipmcd.getCur());
						panel->SetPathView(zipmcd.getCur());
						if (panel->Read(zipmcd.getCur()) == false)
						{
							string dir_name = zipmcd.getCur();
							string dir_name_2 = dir_name.substr(1, dir_name.size() - 1);
			
							panel->Read(dir_name_2);
						}
					}
				}
				catch(Exception& ex)
				{
					MsgBox(1, "Error", "%s", (char*)ex);
				}
			}
		}
			
		void Copy()
		{
			if (!panel->isZip()) panel->cmd_copy();
			else panel->cmd_zip_copy();
		}
		
		void Move()
		{
			if (!panel->isZip()) panel->cmd_move();
		}
		
		void Edit();   /// panel_cmd.cpp 에 구현
		void View();   /// panel_cmd.cpp 에 구현
			
		void Mkdir()
		{
			string p;
			if (InputBox("Make Directory", p)<0) return;
			
			struct stat statbuf;
			
			if (stat(p.c_str(), &statbuf)!=-1)
			{
				MsgBox("Error","Directory exists");
				return;				
			}
			
			if (mkdir(p.c_str(), 0755)==-1)
			{
				MsgBox("Error","Fail to make a directory");
				return;
			}
			Refresh();
			return;
		}
		
		void Rename()
		{
			struct stat statbuf;
			string ren = panel->GetCurrentFile().name;
				
			if (ren == "..") return;
				
			if (InputBox("rename", ren)<0) return;
			
			if (lstat(ren.c_str(), &statbuf) != -1)
			{
				MsgBox("Error", "fail : name exists");
				return;
			}
			
			if (rename(panel->GetCurrentFile().name.c_str(), ren.c_str()) == -1)
			{
				MsgBox("Error", "fail to rename");
				return;
			}
			Refresh();
			panel->Search(ren);
		}
		
		void ViewScreen();
		
		void Back()			{	panel->Read(panel->tHistory.GetPrev());	}
		void Forward()		{	panel->Read(panel->tHistory.GetPrev());	}
			
		void Select() {   panel->ToggleSelect(); }
		void SelectAll() {
			for (int t=0; t<panel->file_list.size(); t++)
				panel->select(*panel->file_list[t]);
		}
		void SelectInvert() {
			for (int t=0; t<panel->file_list.size(); t++)
				if (panel->file_list[t]->selected) panel->deselect(*panel->file_list[t]);			
				else panel->select(*panel->file_list[t]);
		}
		
		
		void ShowHidden()
		{
			e_tConf.ShowHidden = !e_tConf.ShowHidden;
			Refresh();
		}
		
		/// @brief	User로 부터 입력 받은 Shell 명령실행
		void Shell();		
		
		// sort
		void SortName()	{e_tConf.sort = 1;	panel->Sort();	}		
		void SortExt()	{e_tConf.sort = 2;	panel->Sort();	}
		void SortSize()	{e_tConf.sort = 3;	panel->Sort();	}		
		void SortTime()	{e_tConf.sort = 4;	panel->Sort();	}
		void SortColor(){e_tConf.sort = 5;	panel->Sort();	}
		
		void Split() {g_MainFrame->bSplit = !g_MainFrame->bSplit; g_MainFrame->SetSplitWindow(); }
		
		void NextWindow() { g_MainFrame->NextWindow(); }
		
		void GotoRoot() { panel->Read("/"); }
		void GotoHome() { panel->Read(e_tConf.home); }
		void GotoUpperDirectory() { panel->Read(".."); }
				
		void BoxCodeChange()
		{
			if (e_nBoxLineCode == ACSLINE)
				Set_Line(CHARLINE);
			else
				Set_Line(ACSLINE);
		}
		
		void CopyClip();
		void PasteClip();
		void CutClip();
		
}; // class CommandImp
	
}; // namespace 

#endif

==> mls-0.4.tar.gz: mls-0.4/src/commandimp.h <==
#ifndef __MLS_COMMANDIMP_H__
#define __MLS_COMMANDIMP_H__

#include "define.h"
#include "mlslocale.h"
#include "exception.h"
#include "panel.h"
#include "dialog.h"
#include "mainframe.h"
#include "DirMcd.h"
#include "ZipMcd.h"

namespace MLS {

class CommandImp
{
	private:
		Panel *panel;

	public:
		CommandImp() : panel(NULL)	{ 	}
		~CommandImp() { }
		
		void SetPanel(Panel *p) { panel = p; }
		
		int  Run(const std::string &, bool = false, bool = false);
		int  ParseAndRun(const string &p, bool = false);
		
		void Default()			{ }
		
		void Key_Enter()		{ panel->Key_Enter();		}
		void Key_Left()			{ panel->Key_Left();	 	}
		void Key_Right() 		{ panel->Key_Right(); 		}
		void Key_Up () 			{ panel->Key_Up();			}
		void Key_Down () 		{ panel->Key_Down();		}
		void Key_Home () 		{ panel->Key_Home();		}
		void Key_End () 		{ panel->Key_End();			}
		void Key_PageUp() 		{ panel->Key_PageUp();		}
		void Key_PageDown() 	{ panel->Key_PageDown();	}
		
		// other implementations	
		void Remove()		    { panel->cmd_remove();	}
		
		void EditConfig()
		{
			Run(e_tConf.extern_editor + " " + e_tConf.home + ".mls/mls.cfg"); 
			
			e_tConf.load((e_tConf.home + ".mls/mls.cfg").c_str());
			panel->Refresh();
		}
		
		void EditColorset()
		{
			Run(e_tConf.extern_editor + " " + e_tConf.home + ".mls/mls.col");
			panel->Refresh();			
		}
		
		void EditKeybind()
		{
			Run(e_tConf.extern_editor + " " + e_tConf.home + ".mls/mls.key"); 
			panel->Refresh();			
		}
		
		void About() 	{	panel->about();			}
		void Help()  	{	panel->cmd_help();		}
		void Exit()  	
		{
			if (e_tConf.QMlsExit == true)
			{
				int nYN = YNBox(gettext("Do you really want to quit the mls ?"), 0);
				
				if (nYN == YN_N)
				{		
					return;
				}
			}
			
			// 마지막 mls 가 마지막으로 사용한 디렉토리를 저장한다.	
			FILE *fp= fopen((e_tConf.cfghome + "path").c_str(), "wb");
				
			if (fp)
			{
				fputs(panel->GetCurrentPath().c_str(), fp);
				fclose(fp);
			}
			else
			{
				LOG("'path' file write failure !!!");
			}
			g_MainFrame->Exit();
		}
		
		void Menu() 		{	g_MainFrame->tMenu.Process(*panel); }
		void Refresh()		
		{ 
			g_MainFrame->Refresh();
			g_MainFrame->RefreshPanel(); 
		}
		
		void Extract()		{ panel->Key_ZipInstall(); }
		
		void Mcd()
		{
			if (panel->isZip() == false)
			{
				WINDOW*	pWin = NULL;
				
				try
				{
					pWin = MsgWaitBox(	gettext("Wait"),
										gettext(	"Please wait !!! - Cancel Key [ESC]"));
					
					LOG("Mcd !!!");
					MLS::DirMcd mcd;
					mcd.AddDirectory(panel->GetCurrentPath());
					mcd.setCur(panel->GetCurrentPath());
					
					if (pWin) MsgWaitEnd(pWin);
					
					if (mcd.proc()) 
					{
						panel->Read(mcd.getCur());
					}
				}
				catch(Exception& ex)
				{
					MsgBox(1, gettext("Error"), "%s", (char*)ex);
				}
				
				Refresh();
			}
			else
			{
				WINDOW*	pWin = NULL;
				
				try
				{
					string sMcdView;
					
					pWin = MsgWaitBox(	gettext("Wait"),
										gettext("Please wait !!! - Cancel Key [ESC]"));
					
					sMcdView = "Mcd - Mls Change Directory [" + panel->m_sZipFile + "]";
					ZipMcd zipmcd(panel->GetZipFiles(), "/", sMcdView.c_str(), panel->m_sZipFile);
					
					zipmcd.AddDirectory(panel->GetZipCurrentPath());
					zipmcd.setCur(panel->GetZipCurrentPath());
					
					if (pWin) MsgWaitEnd(pWin);
					
					if (zipmcd.proc()) 
					{
						LOG("Current Directory [%s]", (zipmcd.getCur()).c_str());
						panel->SetZipCurrentPath(zipmcd.getCur());
						panel->SetPathView(zipmcd.getCur());
						if (panel->Read(zipmcd.getCur()) == false)
						{
							string dir_name = zipmcd.getCur();
							string dir_name_2 = dir_name.substr(1, dir_name.size() - 1);
			
							panel->Read(dir_name_2);
						}
					}
				}
				catch(Exception& ex)
				{
					MsgBox(1, gettext("Wait"), "%s", (char*)ex);
				}
			}
		}
			
		void Copy()
		{
			if (!panel->isZip()) panel->cmd_copy();
			else panel->cmd_zip_copy();
		}
		
		void Move()
		{
			if (!panel->isZip()) panel->cmd_move();
		}
		
		void Edit();   /// panel_cmd.cpp 에 구현
		void View();   /// panel_cmd.cpp 에 구현
			
		void Mkdir()
		{
			string p;
			if (InputBox(gettext("Make Directory"), p)<0) return;
			
			struct stat statbuf;
			
			if (stat(p.c_str(), &statbuf)!=-1)
			{
				MsgBox(	gettext("Error"),
						gettext("Directory exists"));
				return;				
			}
			
			if (mkdir(p.c_str(), 0755)==-1)
			{
				MsgBox(	gettext("Error"),
						gettext("Fail to make a directory"));
				return;
			}
			Refresh();
			return;
		}
		
		void Rename()
		{
			struct stat statbuf;
			string ren = panel->GetCurrentFile().name;
				
			if (ren == "..") return;
				
			if (InputBox(gettext("rename"), ren)<0) return;
			
			if (lstat(ren.c_str(), &statbuf) != -1)
			{
				MsgBox(	gettext("Error"), 
						gettext("Fail : name exists"));
				return;
			}
			
			if (rename(panel->GetCurrentFile().name.c_str(), ren.c_str()) == -1)
			{
				MsgBox(	gettext("Error"), 
						gettext("Fail to rename"));
				return;
			}
			Refresh();
			panel->Search(ren);
		}
		
		void ViewScreen();
		
		void Back()			{	panel->Read(panel->tHistory.GetPrev());	}
		void Forward()		{	panel->Read(panel->tHistory.GetPrev());	}
			
		void Select() {   panel->ToggleSelect(); }
		void SelectAll() {
			for (int t=0; t<panel->file_list.size(); t++)
				panel->select(*panel->file_list[t]);
		}
		void SelectInvert() {
			for (int t=0; t<panel->file_list.size(); t++)
				if (panel->file_list[t]->selected) panel->deselect(*panel->file_list[t]);			
				else panel->select(*panel->file_list[t]);
		}
		
		
		void ShowHidden()
		{
			e_tConf.ShowHidden = !e_tConf.ShowHidden;
			Refresh();
		}
		
		/// @brief	User로 부터 입력 받은 Shell 명령실행
		void Shell();		
		
		// sort
		void SortName()	{e_tConf.sort = 1;	panel->Sort();	}		
		void SortExt()	{e_tConf.sort = 2;	panel->Sort();	}
		void SortSize()	{e_tConf.sort = 3;	panel->Sort();	}		
		void SortTime()	{e_tConf.sort = 4;	panel->Sort();	}
		void SortColor(){e_tConf.sort = 5;	panel->Sort();	}
		
		void Split() {g_MainFrame->bSplit = !g_MainFrame->bSplit; g_MainFrame->SetSplitWindow(); }
		
		void NextWindow() { g_MainFrame->NextWindow(); }
		
		void GotoRoot() { panel->Read("/"); }
		void GotoHome() { panel->Read(e_tConf.home); }
		void GotoUpperDirectory() { panel->Read(".."); }
				
		void BoxCodeChange()
		{
			if (e_nBoxLineCode == ACSLINE)
				Set_Line(CHARLINE);
			else
				Set_Line(ACSLINE);
		}
		
		void LangChange()
		{
			if (e_nCurLang == US)
			{
				Set_Locale(AUTO);
				g_MainFrame->ReloadMenu();
			}
			else
			{
				Set_Locale(US);
				g_MainFrame->ReloadMenu();
			}
		}
		
		void CopyClip();
		void PasteClip();
		void CutClip();
		
}; // class CommandImp
	
}; // namespace 

#endif
